@@ -19,11 +19,13 @@ occ2sps <- function(DHA, DHB, model=NULL, data=NULL, ci=0.95, verify=TRUE)  {
   DHA <- as.matrix(DHA)
   DHB <- as.matrix(DHB)
   if(verify) {
-    stopifnot(all.equal(dim(DHA), dim(DHB)))
+    if(!all.equal(dim(DHA), dim(DHB)))
+      stop("DHA and DHB must have the same number of rows and columns.")
     DHA <- verifyDH(DHA, allowNA = TRUE)
     DHB <- verifyDH(DHB, allowNA = TRUE)
     # Check that the NAs match up
-    stopifnot(all.equal(is.na(DHA), is.na(DHB), check.attributes=FALSE))
+    if(!all.equal(is.na(DHA), is.na(DHB), check.attributes=FALSE))
+      stop("DHA and DHB must have missing values for the same surveys.")
   }
 
   # Standardise the model:
@@ -81,35 +83,7 @@ occ2sps <- function(DHA, DHB, model=NULL, data=NULL, ci=0.95, verify=TRUE)  {
   coefNames <- paste(rep(names(model), parK),
       unlist(lapply(modMatList, colnames)), sep=":")
 
-  # function to get the occupancy matrix
-  # psiX is a matrix with columns psiA, psiBa, psiBA
-  getlogPHI <- function(psiX) {
-    log(cbind(psiX[, 1] * psiX[, 3],             # both
-      psiX[, 1] * (1 - psiX[, 3]),       # A only
-      (1 - psiX[, 1]) * psiX[, 2],       # B only
-      (1 - psiX[, 1]) * (1 - psiX[, 2]))) # neither
-  }
-
-  # Do the detection vector for one site
-  # pX is a vector with elements pA, pB, rA, rBa, rBA
-  getlogP <- function(dhA, dhB, pX)  {
-    # prob of detecting B if both present conditional on detection of A
-    probCapB <- dhA * pX[5] + (1 - dhA) * pX[4]
-    c(
-      # Both sps present, use the r's
-      sum(log(dhA * pX[3] + (1 - dhA) * (1 - pX[3])),      # A
-        log(dhB * probCapB + (1 - dhB) * (1 - probCapB)), na.rm=TRUE),  # B
-      # Sps A present, B absent, use pA
-      if(sum(dhB, na.rm=TRUE) > 0) { -Inf } else {
-        sum(log(dhA * pX[1] + (1 - dhA) * (1 - pX[1])), na.rm=TRUE) # A
-      },
-      # Sps A absent, B present, use pB
-      if(sum(dhA, na.rm=TRUE) > 0) { -Inf } else {
-        sum(log(dhB * pX[2] + (1 - dhB) * (1 - pX[2])), na.rm=TRUE) # B
-      },
-      # Neither present
-      if(sum(dhA, dhB, na.rm=TRUE) > 0) { -Inf } else { 0 } )
-  }
+  # Functions getlogPHI and getlogP moved to file occ2sps_utils.R 2017-10-30
 
   # objects to hold output
   beta.mat <- matrix(NA_real_, K, 4)
@@ -122,17 +96,16 @@ occ2sps <- function(DHA, DHB, model=NULL, data=NULL, ci=0.95, verify=TRUE)  {
   rownames(lp.mat) <- as.vector(t(outer(parNames, site.names, paste, sep=":")))
 
   # Do the neg log lik function:
-  real0 <- matrix(NA, nSites, M)
+  logitreal0 <- matrix(NA, nSites, M)
   nll <- function(params) {
     for(i in 1:M) {
       betas <- params[idK == i]
-      real0[, i] <- plogis(modMatList[[i]] %*% betas)
+      logitreal0[, i] <- modMatList[[i]] %*% betas
     }
-    real <- real0[, modPars]
-    logPHI <- getlogPHI(real[, 1:3])
-    loglik <- numeric(nSites)
-    for(i in 1:nSites)
-      loglik[i] <- logSumExp(logPHI[i, ] + getlogP(dhA=DHA[i, ], dhB=DHB[i, ], pX=real[i, 4:8]) )
+    logitreal <- logitreal0[, modPars]
+    logPHI <- getlogPHI(logitreal[, 1:3]) ### pass logit to getlogPHI
+    logP <- getlogP(DHA, DHB, logitreal[, 4:8]) ### pass logit to getlogP
+    loglik <- apply(logPHI + logP, 1, logSumExp)
     return(min(-sum(loglik), .Machine$double.xmax))
   }
 
@@ -163,8 +136,9 @@ occ2sps <- function(DHA, DHB, model=NULL, data=NULL, ci=0.95, verify=TRUE)  {
   }
   SElp0 <- matrix(NA, nSites, M)
   for(i in 1:M) {
-    varcov1 <- varcov[idK == i, idK == i]
-    SElp0[, i] <- sqrt(diag(modMatList[[i]] %*% varcov1 %*% t(modMatList[[i]])))
+    # varcov1 <- varcov[idK == i, idK == i]
+    # SElp0[, i] <- sqrt(diag(modMatList[[i]] %*% varcov1 %*% t(modMatList[[i]])))
+    SElp0[, i] <- sqrt(getFittedVar(modMatList[[i]], varcov[idK == i, idK == i]))
   }
   SElp <- as.vector(SElp0[, modPars])
   lp.mat[, 2:3] <- sweep(outer(SElp, crit), 1, lp.mat[, 1], "+")
